@@ -2,6 +2,7 @@ import os
 import unittest
 
 from tests.db.test_generic import TestWBDBManager
+from wbtools.db.paper import WBPaperDBManager
 from wbtools.lib.nlp.common import PaperSections
 from wbtools.literature.paper import WBPaper
 
@@ -39,20 +40,27 @@ class TestWBPaper(unittest.TestCase):
                                                      "local_config", "db.cfg")), "Test DB config file not present")
     def test_load_curation_info_from_db(self):
         config = TestWBDBManager.read_db_config()
-        paper = WBPaper()
+        paper = WBPaper(paper_id="00004161", db_manager=WBPaperDBManager(
+            dbname=config["wb_database"]["db_name"], user=config["wb_database"]["db_user"],
+            password=config["wb_database"]["db_password"], host=config["wb_database"]["db_host"]))
         paper.paper_id = "00004161"
-        paper.load_curation_info_from_db(db_name=config["wb_database"]["db_name"], db_user=config["wb_database"]["db_user"],
-                                         db_password=config["wb_database"]["db_password"],
-                                         db_host=config["wb_database"]["db_host"])
+        paper.load_curation_info_from_db()
         self.assertTrue(paper.aut_class_values["seqchange"] == 'high')
 
     @unittest.skipIf(not os.path.exists(os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", "data",
                                                      "local_config", "db.cfg")), "Test DB config file not present")
     def test_load_bib_info_from_db(self):
         config = TestWBDBManager.read_db_config()
-        paper = WBPaper()
-        paper.paper_id = "00004161"
-        paper.load_bib_info_from_db(db_name=config["wb_database"]["db_name"], db_user=config["wb_database"]["db_user"],
-                                    db_password=config["wb_database"]["db_password"],
-                                    db_host=config["wb_database"]["db_host"])
+        paper = WBPaper(paper_id="00004161", db_manager=WBPaperDBManager(
+            dbname=config["wb_database"]["db_name"], user=config["wb_database"]["db_user"],
+            password=config["wb_database"]["db_password"], host=config["wb_database"]["db_host"]))
+        paper.load_bib_info_from_db()
         self.assertGreater(len(paper.authors), 0)
+
+    def test_extract_all_email_addresses_from_text(self):
+        paper = WBPaper()
+        paper.add_file(dir_path=TESTDATA_DIR, filename='00026804_McCracken05.txt', remote_file=False, pdf=False)
+        self.assertTrue(paper.has_same_wbpaper_id_as_filename('00026804_McCracken05.txt'))
+        paper.add_file(dir_path=TESTDATA_DIR, filename='00026804_McCracken05_supp.txt', remote_file=False, pdf=False)
+        addresses = paper.extract_all_email_addresses_from_text()
+        self.assertGreater(len(addresses), 0)
