@@ -1,6 +1,7 @@
 import logging
 
 from wbtools.db.expression import WBExpressionDBManager
+from wbtools.db.gene import WBGeneDBManager
 from wbtools.db.generic import WBGenericDBManager
 from wbtools.db.paper import WBPaperDBManager
 from wbtools.db.person import WBPersonDBManager
@@ -15,3 +16,4 @@ class WBDBManager(object):
         self.expression = WBExpressionDBManager(dbname, user, password, host)
         self.paper = WBPaperDBManager(dbname, user, password, host)
         self.person = WBPersonDBManager(dbname, user, password, host)
+        self.gene = WBGeneDBManager(dbname, user, password, host)
