@@ -1,4 +1,5 @@
 import logging
+from collections import defaultdict
 from typing import List
 
 import psycopg2
@@ -22,8 +23,13 @@ class WBGenericDBManager(AbstractWBDBManager):
                          (added_or_modified_after, ))
             res = curs.fetchall()
             exclude_ids = set(exclude_ids) if exclude_ids else set()
-            return list(set([row[0] for row in res if row[0] not in exclude_ids and "WBPaper" + row[0] not in
-                             exclude_ids])) if res else []
+            paper_ids_time = [(row[0], row[1]) for row in res if row[0] not in exclude_ids and "WBPaper" + row[0] not in
+                              exclude_ids] if res else []
+            paper_id_timestamps = defaultdict(list)
+            for paper_id, timestamp in paper_ids_time:
+                paper_id_timestamps[paper_id].append(timestamp)
+            paper_id_maxtime = {paper_id: max(timestamps) for paper_id, timestamps in paper_id_timestamps.items()}
+            return sorted(list(set(paper_id_maxtime.keys())), reverse=True, key=lambda x : paper_id_maxtime[x])
 
     def get_paper_ids_with_pap_types(self, pap_types: List[str]):
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
